@@ -406,10 +406,11 @@ class BaseNode:
         Stops the telnet proxy.
         """
 
-        if self._wrapper_telnet_server:
+        if self._wrap_console_writer:
             self._wrap_console_writer.close()
-            if sys.version_info >= (3, 7, 0):
-                await self._wrap_console_writer.wait_closed()
+            await self._wrap_console_writer.wait_closed()
+            self._wrap_console_writer = None
+        if self._wrapper_telnet_server:
             self._wrapper_telnet_server.close()
             await self._wrapper_telnet_server.wait_closed()
             self._wrapper_telnet_server = None
@@ -653,9 +654,13 @@ class BaseNode:
         """
 
         path = self._manager.config.get_section_config("Server").get("ubridge_path", "ubridge")
+        if sys.platform.startswith("win") and hasattr(sys, "frozen"):
+            ubridge_dir = os.path.normpath(os.path.join(os.path.dirname(os.path.abspath(sys.executable)), "ubridge"))
+            os.environ["PATH"] = os.pathsep.join(ubridge_dir) + os.pathsep + os.environ.get("PATH", "")
         path = shutil.which(path)
         return path
 
+    @locking
     async def _ubridge_send(self, command):
         """
         Sends a command to uBridge hypervisor.
