@@ -465,6 +465,10 @@ class VMwareVM(BaseNode):
 
         try:
             if self._ubridge_hypervisor:
+                if parse_version(platform.mac_ver()[0]) >= parse_version("11.0.0"):
+                    # give VMware some time to create the bridge interfaces, so they can be found
+                    # by psutil and used by uBridge
+                    await asyncio.sleep(1)
                 for adapter_number in range(0, self._adapters):
                     nio = self._ethernet_adapters[adapter_number].get_nio(0)
                     if nio:
@@ -891,6 +895,14 @@ class VMwareVM(BaseNode):
             self._remote_pipe.close()
             self._telnet_server = None
 
+    async def reset_console(self):
+        """
+        Reset the console.
+        """
+
+        await self._stop_remote_console()
+        await self._start_console()
+
     @BaseNode.console_type.setter
     def console_type(self, new_console_type):
         """
