@@ -15,6 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import sys
 import re
 import os
 import json
@@ -27,6 +28,7 @@ import aiohttp
 import aiofiles
 import tempfile
 import zipfile
+import pathlib
 
 from uuid import UUID, uuid4
 
@@ -42,8 +44,9 @@ from ..utils.application_id import get_next_application_id
 from ..utils.asyncio.pool import Pool
 from ..utils.asyncio import locking
 from ..utils.asyncio import aiozipstream
+from ..utils.asyncio import wait_run_in_executor
 from .export_project import export_project
-from .import_project import import_project
+from .import_project import import_project, _move_node_file
 
 import logging
 log = logging.getLogger(__name__)
@@ -130,16 +133,27 @@ class Project:
         self._iou_id_lock = asyncio.Lock()
 
         log.debug('Project "{name}" [{id}] loaded'.format(name=self.name, id=self._id))
+        self.emit_controller_notification("project.created", self.__json__())
 
     def emit_notification(self, action, event):
         """
-        Emit a notification to all clients using this project.
+        Emit a project notification to all clients using this project.
 
         :param action: Action name
         :param event: Event to send
         """
 
-        self.controller.notification.project_emit(action, event, project_id=self.id)
+        self._controller.notification.project_emit(action, event, project_id=self.id)
+
+    def emit_controller_notification(self, action, event):
+        """
+        Emit a controller notification, all clients will see it.
+
+        :param action: Action name
+        :param event: Event to send
+        """
+
+        self._controller.notification.controller_emit(action, event)
 
     async def update(self, **kwargs):
         """
@@ -154,7 +168,7 @@ class Project:
 
         # We send notif only if object has changed
         if old_json != self.__json__():
-            self.emit_notification("project.updated", self.__json__())
+            self.emit_controller_notification("project.updated", self.__json__())
             self.dump()
 
             # update on computes
@@ -181,7 +195,11 @@ class Project:
         if os.path.exists(snapshot_dir):
             for snap in os.listdir(snapshot_dir):
                 if snap.endswith(".gns3project"):
-                    snapshot = Snapshot(self, filename=snap)
+                    try:
+                        snapshot = Snapshot(self, filename=snap)
+                    except ValueError:
+                        log.error("Invalid snapshot file: {}".format(snap))
+                        continue
                     self._snapshots[snapshot.id] = snapshot
 
         # Create the project on demand on the compute node
@@ -798,12 +816,13 @@ class Project:
             try:
                 await compute.post("/projects/{}/close".format(self._id), dont_connect=True)
             # We don't care if a compute is down at this step
-            except (ComputeError, aiohttp.web.HTTPError, aiohttp.ClientResponseError, TimeoutError):
+            except (ComputeError, aiohttp.web.HTTPError, aiohttp.ClientError, TimeoutError):
                 pass
         self._clean_pictures()
         self._status = "closed"
         if not ignore_notification:
-            self.emit_notification("project.closed", self.__json__())
+            self.emit_controller_notification("project.closed", self.__json__())
+
         self.reset()
         self._closing = False
 
@@ -857,6 +876,7 @@ class Project:
             shutil.rmtree(self.path)
         except OSError as e:
             raise aiohttp.web.HTTPConflict(text="Cannot delete project directory {}: {}".format(self.path, str(e)))
+        self.emit_controller_notification("project.deleted", self.__json__())
 
     async def delete_on_computes(self):
         """
@@ -976,7 +996,7 @@ class Project:
                 await self.add_drawing(dump=False, **drawing_data)
 
             self.dump()
-        # We catch all error to be able to rollback the .gns3 to the previous state
+        # We catch all error to be able to roll back the .gns3 to the previous state
         except Exception as e:
             for compute in list(self._project_created_on_compute):
                 try:
@@ -1001,6 +1021,7 @@ class Project:
             pass
 
         self._loading = False
+        self.emit_controller_notification("project.opened", self.__json__())
         # Should we start the nodes when project is open
         if self._auto_start:
             # Start all in the background without waiting for completion
@@ -1019,14 +1040,16 @@ class Project:
         """
         Duplicate a project
 
-        It's the save as feature of the 1.X. It's implemented on top of the
-        export / import features. It will generate a gns3p and reimport it.
-        It's a little slower but we have only one implementation to maintain.
+        Implemented on top of the export / import features. It will generate a gns3p and reimport it.
+
+        NEW: fast duplication is used if possible (when there are no remote computes).
+        If not, the project is exported and reimported as explained above.
 
         :param name: Name of the new project. A new one will be generated in case of conflicts
         :param location: Parent directory of the new project
         :param reset_mac_addresses: Reset MAC addresses for the new project
         """
+
         # If the project was not open we open it temporary
         previous_status = self._status
         if self._status == "closed":
@@ -1034,6 +1057,18 @@ class Project:
 
         self.dump()
         assert self._status != "closed"
+
+        try:
+            proj = await self._fast_duplication(name, location, reset_mac_addresses)
+            if proj:
+                if previous_status == "closed":
+                    await self.close()
+                return proj
+            else:
+                log.info("Fast duplication failed, fallback to normal duplication")
+        except Exception as e:
+            raise aiohttp.web.HTTPConflict(text="Cannot duplicate project: {}".format(str(e)))
+
         try:
             begin = time.time()
 
@@ -1048,7 +1083,7 @@ class Project:
             with tempfile.TemporaryDirectory(dir=working_dir) as tmpdir:
                 # Do not compress the exported project when duplicating
                 with aiozipstream.ZipFile(compression=zipfile.ZIP_STORED) as zstream:
-                    await export_project(zstream, self, tmpdir, keep_compute_id=True, allow_all_nodes=True, reset_mac_addresses=reset_mac_addresses)
+                    await export_project(zstream, self, tmpdir, keep_compute_ids=True, allow_all_nodes=True, reset_mac_addresses=reset_mac_addresses)
 
                     # export the project to a temporary location
                     project_path = os.path.join(tmpdir, "project.gns3p")
@@ -1059,7 +1094,7 @@ class Project:
 
                     # import the temporary project
                     with open(project_path, "rb") as f:
-                        project = await import_project(self._controller, str(uuid.uuid4()), f, location=location, name=name, keep_compute_id=True)
+                        project = await import_project(self._controller, str(uuid.uuid4()), f, location=location, name=name, keep_compute_ids=True)
 
             log.info("Project '{}' duplicated in {:.4f} seconds".format(project.name, time.time() - begin))
         except (ValueError, OSError, UnicodeEncodeError) as e:
@@ -1219,3 +1254,70 @@ class Project:
 
     def __repr__(self):
         return "<gns3server.controller.Project {} {}>".format(self._name, self._id)
+
+    async def _fast_duplication(self, name=None, location=None, reset_mac_addresses=True):
+        """
+        Fast duplication of a project.
+
+        Copy the project files directly rather than in an import-export fashion.
+
+        :param name: Name of the new project. A new one will be generated in case of conflicts
+        :param location: Parent directory of the new project
+        :param reset_mac_addresses: Reset MAC addresses for the new project
+        """
+
+        # remote replication is not supported with remote computes
+        for compute in self.computes:
+            if compute.id != "local":
+                log.warning("Fast duplication is not supported with remote compute: '{}'".format(compute.id))
+                return None
+        # work dir
+        p_work = pathlib.Path(location or self.path).parent.absolute()
+        t0 = time.time()
+        new_project_id = str(uuid.uuid4())
+        new_project_path = p_work.joinpath(new_project_id)
+        # copy dir
+        await wait_run_in_executor(shutil.copytree, self.path, new_project_path.as_posix(), symlinks=True, ignore_dangling_symlinks=True)
+        log.info("Project content copied from '{}' to '{}' in {}s".format(self.path, new_project_path, time.time() - t0))
+        topology = json.loads(new_project_path.joinpath('{}.gns3'.format(self.name)).read_bytes())
+        project_name = name or topology["name"]
+        # If the project name is already used we generate a new one
+        project_name = self.controller.get_free_project_name(project_name)
+        topology["name"] = project_name
+        # To avoid unexpected behavior (project start without manual operations just after import)
+        topology["auto_start"] = False
+        topology["auto_open"] = False
+        topology["auto_close"] = False
+        # change node ID
+        node_old_to_new = {}
+        for node in topology["topology"]["nodes"]:
+            new_node_id = str(uuid.uuid4())
+            if "node_id" in node:
+                node_old_to_new[node["node_id"]] = new_node_id
+                _move_node_file(new_project_path, node["node_id"], new_node_id)
+            node["node_id"] = new_node_id
+            if reset_mac_addresses:
+                if "properties" in node:
+                    for prop, value in node["properties"].items():
+                        # reset the MAC address
+                        if prop in ("mac_addr", "mac_address"):
+                            node["properties"][prop] = None
+        # change link ID
+        for link in topology["topology"]["links"]:
+            link["link_id"] = str(uuid.uuid4())
+            for node in link["nodes"]:
+                node["node_id"] = node_old_to_new[node["node_id"]]
+        # Generate new drawings id
+        for drawing in topology["topology"]["drawings"]:
+            drawing["drawing_id"] = str(uuid.uuid4())
+
+        # And we dump the updated.gns3
+        dot_gns3_path = new_project_path.joinpath('{}.gns3'.format(project_name))
+        topology["project_id"] = new_project_id
+        with open(dot_gns3_path, "w+") as f:
+            json.dump(topology, f, indent=4)
+
+        os.remove(new_project_path.joinpath('{}.gns3'.format(self.name)))
+        project = await self.controller.load_project(dot_gns3_path, load=False)
+        log.info("Project '{}' fast duplicated in {:.4f} seconds".format(project.name, time.time() - t0))
+        return project
