@@ -188,7 +188,7 @@ def load_topology(path):
     try:
         _check_topology_schema(topo)
     except aiohttp.web.HTTPConflict as e:
-        log.error("Can't load the topology %s", path)
+        log.error("Can't load the topology %s, please check using the debug mode...", path)
         raise e
 
     if changed:
@@ -223,7 +223,7 @@ def _convert_2_1_0(topo, topo_path):
             if node["node_type"] in ("qemu", "vmware", "virtualbox"):
                 if "acpi_shutdown" in node["properties"]:
                     if node["properties"]["acpi_shutdown"] is True:
-                        node["properties"]["on_close"] = "save_vm_sate"
+                        node["properties"]["on_close"] = "save_vm_state"
                     else:
                         node["properties"]["on_close"] = "power_off"
                     del node["properties"]["acpi_shutdown"]
