@@ -32,7 +32,6 @@ import distro
 
 from .version import __version__, __version_info__
 from .config import Config
-from .utils.get_resource import get_resource
 
 import logging
 log = logging.getLogger(__name__)
@@ -58,7 +57,7 @@ class CrashReport:
     Report crash to a third party service
     """
 
-    DSN = "https://4f6a87fd456f468ab0a87ecbc97ed8fb@o19455.ingest.sentry.io/38482"
+    DSN = "https://088679fcf3aa35f775356982a80fe37c@o19455.ingest.us.sentry.io/38482"
     _instance = None
 
     def __init__(self):
@@ -71,22 +70,16 @@ class CrashReport:
         sentry_uncaught.disabled = True
 
         if SENTRY_SDK_AVAILABLE:
-            cacert = None
-            if hasattr(sys, "frozen"):
-                cacert_resource = get_resource("cacert.pem")
-                if cacert_resource is not None and os.path.isfile(cacert_resource):
-                    cacert = cacert_resource
-                else:
-                    log.error("The SSL certificate bundle file '{}' could not be found".format(cacert_resource))
-
             # Don't send log records as events.
             sentry_logging = LoggingIntegration(level=logging.INFO, event_level=None)
-
-            sentry_sdk.init(dsn=CrashReport.DSN,
-                            release=__version__,
-                            ca_certs=cacert,
-                            default_integrations=False,
-                            integrations=[sentry_logging])
+            try:
+                sentry_sdk.init(dsn=CrashReport.DSN,
+                                release=__version__,
+                                default_integrations=False,
+                                integrations=[sentry_logging])
+            except Exception as e:
+                log.error("Crash report could not be sent: {}".format(e))
+                return
 
             tags = {
                 "os:name": platform.system(),
