@@ -31,7 +31,7 @@ def nio():
 
 
 @pytest.fixture
-async def manager(loop):
+async def manager():
 
     m = MagicMock()
     m.module_name = "builtins"
@@ -113,7 +113,7 @@ def test_json_without_ports(on_gns3vm, compute_project, manager):
     }
 
 
-async def test_update_port_mappings(loop, on_gns3vm, compute_project):
+async def test_update_port_mappings(on_gns3vm, compute_project):
     """
     We don't allow an empty interface in the middle of port list
     """
@@ -153,7 +153,7 @@ async def test_update_port_mappings(loop, on_gns3vm, compute_project):
     assert cloud.ports_mapping == ports1
 
 
-async def test_linux_ethernet_raw_add_nio(loop, linux_platform, compute_project, nio):
+async def test_linux_ethernet_raw_add_nio(linux_platform, compute_project, nio):
     ports = [
         {
             "interface": "eth0",
@@ -180,7 +180,7 @@ async def test_linux_ethernet_raw_add_nio(loop, linux_platform, compute_project,
     ])
 
 
-async def test_linux_ethernet_raw_add_nio_bridge(loop, linux_platform, compute_project, nio):
+async def test_linux_ethernet_raw_add_nio_bridge(linux_platform, compute_project, nio):
     """
     Bridge can't be connected directly to a cloud we use a tap in the middle
     """
