@@ -48,6 +48,7 @@ async def vm(compute_project, manager):
     vm = DockerVM("test", str(uuid.uuid4()), compute_project, manager, "ubuntu:latest")
     vm._cid = "e90e34656842"
     vm.allocate_aux = False
+    vm.mac_address = '02:42:3d:b7:93:00'
     return vm
 
 
@@ -60,6 +61,7 @@ def test_json(vm, compute_project):
         'project_id': compute_project.id,
         'node_id': vm.id,
         'adapters': 1,
+        'mac_address': '02:42:3d:b7:93:00',
         'console': vm.console,
         'console_type': 'telnet',
         'console_resolution': '1024x768',
@@ -105,7 +107,8 @@ async def test_create(compute_project, manager):
                             "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -143,7 +146,8 @@ async def test_create_with_tag(compute_project, manager):
                             "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -185,7 +189,8 @@ async def test_create_vnc(compute_project, manager):
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
                             "/tmp/.X11-unix/X{0}:/tmp/.X11-unix/X{0}:ro".format(vm._display)
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -314,7 +319,8 @@ async def test_create_start_cmd(compute_project, manager):
                             "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "Entrypoint": ["/gns3/init.sh"],
@@ -412,7 +418,8 @@ async def test_create_image_not_available(compute_project, manager):
                             "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -455,7 +462,8 @@ async def test_create_with_user(compute_project, manager):
                             "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -538,7 +546,8 @@ async def test_create_with_extra_volumes_duplicate_1_image(compute_project, mana
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
                             "{}:/gns3volumes/vol/1".format(os.path.join(vm.working_dir, "vol", "1")),
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -577,7 +586,8 @@ async def test_create_with_extra_volumes_duplicate_2_user(compute_project, manag
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
                             "{}:/gns3volumes/vol/1".format(os.path.join(vm.working_dir, "vol", "1")),
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -616,7 +626,8 @@ async def test_create_with_extra_volumes_duplicate_3_subdir(compute_project, man
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
                             "{}:/gns3volumes/vol".format(os.path.join(vm.working_dir, "vol")),
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -655,7 +666,8 @@ async def test_create_with_extra_volumes_duplicate_4_backslash(compute_project,
                             "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network")),
                             "{}:/gns3volumes/vol".format(os.path.join(vm.working_dir, "vol")),
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -693,7 +705,8 @@ async def test_create_with_extra_volumes_duplicate_5_subdir_issue_1595(compute_p
                             "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc".format(os.path.join(vm.working_dir, "etc")),
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -731,7 +744,8 @@ async def test_create_with_extra_volumes_duplicate_6_subdir_issue_1595(compute_p
                             "{}:/gns3:ro".format(Docker.resources_path()),
                             "{}:/gns3volumes/etc".format(os.path.join(vm.working_dir, "etc")),
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -777,7 +791,8 @@ async def test_create_with_extra_volumes(compute_project, manager):
                             "{}:/gns3volumes/vol/1".format(os.path.join(vm.working_dir, "vol", "1")),
                             "{}:/gns3volumes/vol/2".format(os.path.join(vm.working_dir, "vol", "2")),
                         ],
-                        "Privileged": True
+                        "Privileged": True,
+                        "UsernsMode": "host"
                     },
                 "Volumes": {},
                 "NetworkDisabled": True,
@@ -1025,7 +1040,8 @@ async def test_update(vm):
                 "{}:/gns3:ro".format(Docker.resources_path()),
                 "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
             ],
-            "Privileged": True
+            "Privileged": True,
+            "UsernsMode": "host"
         },
         "Volumes": {},
         "NetworkDisabled": True,
@@ -1093,7 +1109,8 @@ async def test_update_running(vm):
                 "{}:/gns3:ro".format(Docker.resources_path()),
                 "{}:/gns3volumes/etc/network".format(os.path.join(vm.working_dir, "etc", "network"))
             ],
-            "Privileged": True
+            "Privileged": True,
+            "UsernsMode": "host"
         },
         "Volumes": {},
         "NetworkDisabled": True,
@@ -1185,7 +1202,37 @@ async def test_add_ubridge_connection(vm):
         call.send('bridge start bridge0')
     ]
     assert 'bridge0' in vm._bridges
-    # We need to check any_order ortherwise mock is confused by asyncio
+    # We need to check any_order otherwise mock is confused by asyncio
+    vm._ubridge_hypervisor.assert_has_calls(calls, any_order=True)
+
+
+async def test_add_ubridge_connections_with_base_mac_address(vm):
+
+    vm._ubridge_hypervisor = MagicMock()
+    vm._namespace = 42
+    vm.adapters = 2
+    vm.mac_address = "02:42:42:42:42:00"
+
+    nio_params = {
+        "type": "nio_udp",
+        "lport": 4242,
+        "rport": 4343,
+        "rhost": "127.0.0.1"}
+
+    nio = vm.manager.create_nio(nio_params)
+    await vm._add_ubridge_connection(nio, 0)
+
+    nio = vm.manager.create_nio(nio_params)
+    await vm._add_ubridge_connection(nio, 1)
+
+    calls = [
+        call.send('bridge create bridge0'),
+        call.send('bridge create bridge1'),
+        call.send('docker set_mac_addr tap-gns3-e0 02:42:42:42:42:00'),
+        call.send('docker set_mac_addr tap-gns3-e0 02:42:42:42:42:01')
+    ]
+
+    # We need to check any_order otherwise mock is confused by asyncio
     vm._ubridge_hypervisor.assert_has_calls(calls, any_order=True)
 
 
