@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2015 GNS3 Technologies Inc.
+# Copyright (C) 2020 GNS3 Technologies Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,15 +19,17 @@ import os
 import pytest
 
 
-def test_udp_allocation(http_compute, project):
-    response = http_compute.post('/projects/{}/ports/udp'.format(project.id), {}, example=True)
+async def test_udp_allocation(compute_api, compute_project):
+
+    response = await compute_api.post('/projects/{}/ports/udp'.format(compute_project.id), {})
     assert response.status == 201
     assert response.json['udp_port'] is not None
 
 
 # Netfifaces is not available on Travis
 @pytest.mark.skipif(os.environ.get("TRAVIS", False) is not False, reason="Not supported on Travis")
-def test_interfaces(http_compute):
-    response = http_compute.get('/network/interfaces', example=True)
+async def test_interfaces(compute_api):
+
+    response = await compute_api.get('/network/interfaces')
     assert response.status == 200
     assert isinstance(response.json, list)
