@@ -952,6 +952,6 @@ async def test_create_node_from_template(controller_api, controller, project):
             "x": 42,
             "y": 12
         })
-    mock.assert_called_with(id, x=42, y=12, compute_id=None)
+    mock.assert_called_with(id, x=42, y=12, name=None, compute_id=None)
     assert response.route == "/projects/{project_id}/templates/{template_id}"
     assert response.status == 201
